empix
=====

``empix`` is a Python library that contains tools for analyzing electron
microscopy data that are not available in hyperspy_.

.. _hyperspy: https://hyperspy.org/hyperspy-doc/current/index.html

Setting up empix
----------------

For instructions on installing the ``empix`` library, see the
:ref:`installation_instructions_sec` page.

Learning how to use empix
-------------------------

For those new to the ``empix`` library, it is recommended that they take a look
at the :ref:`examples_sec` page, which contain code examples that show how one
can use the ``empix`` library. While going through the examples, readers can
consult the :ref:`reference_guide_sec` to understand what each line of code is
doing.

Contents
--------
.. toctree::
   :maxdepth: 6
   :numbered:

   Home <self>
   INSTALL
   Reference <_autosummary/empix>
   examples
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
